#================================================================================
#◆クリップボードの画像を3倍に拡大か1/3に縮小してクリップボードに保存するツール
#［バージョン］1.01
#［最終更新日］2022/11/10
#［公開日　　］2022/10/10
#［作成者　　］SpareBlade(http://tomatoes.michikusa.jp)
#［概要　　　］クリップボードにコピーされている画像を
#　　　　　　　3倍に拡大、もしくは1/3に縮小したうえでクリップボードに上書き保存します。
#［更新履歴　］
#　2022/11/10 ver1.01：ボタンの文字色を変更(どっちが拡大か一瞬わからなくなるので…)
#　2022/10/10 ver1.00：新規公開
#================================================================================
import tkinter as tk
import tkinter.filedialog as fd
from tkinter import messagebox

import win32clipboard
import io

from PIL import ImageGrab, Image, ImageTk

#--------------------------------------------------
#↓クリップボードにコピーする処理　https://water2litter.net/rum/post/python_win32clipboard_set/
def copy_to_clipboard():
    # メモリストリームにBMP形式で保存してから読み出す
    output = io.BytesIO()
    img2.convert('RGB').save(output, 'BMP')
    data = output.getvalue()[14:]
    output.close()
    send_to_clipboard(win32clipboard.CF_DIB, data)

def send_to_clipboard(clip_type, data):
    # クリップボードをクリアして、データをセットする
    win32clipboard.OpenClipboard()
    win32clipboard.EmptyClipboard()
    win32clipboard.SetClipboardData(clip_type, data)
    win32clipboard.CloseClipboard()

#--------------------------------------------------
def mainShori(mode):
    #編集元の画像をクリップボードから取得
    img1 = ImageGrab.grabclipboard()

    #クリップボードから取得したものが画像だった場合のみ、処理を行う
    if isinstance(img1, Image.Image):
        #true
        global img2
        img2 = img1

        resizeX = img2.width
        resizeY = img2.height

        if mode == 0:
            resizeX = resizeX * 3
            resizeY = resizeY * 3
        elif mode == 1:

            if resizeX % 3 > 0 and resizeY % 3 > 0 :
                messagebox.showinfo("情報","画像サイズが1/3で割り切れませんでした。\n「拡大」と「縮小」のボタンを押し間違えていない？？")
                return 0
            else:
                resizeX = resizeX // 3
                resizeY = resizeY // 3

        img2 = img2.resize(((resizeX,resizeY)), resample=None, box=None, reducing_gap=None)

        print("x:",resizeX,"Y:",resizeY)

        #global imageData #★PhotoImageを関数から呼び出す時、こいつがないとこの関数が終わった瞬間画像が消えてしまう（超悩んだ。ホントクソ）　https://lrcgf.hatenablog.com/entry/2013/06/30/222918
        #imageData = ImageTk.PhotoImage(img2)
        #imageLabel.configure(image=imageData)
        #imageLabel.image=imageLabel

        copy_to_clipboard()
        print("true")
        return 1

    else:
        #false
        messagebox.showinfo("情報","画像がクリップボードにコピーされていません")
        print("else")
        return 0

#--------------------------------------------------
def kakudai():
    kekka = mainShori(0)
    if kekka == 1:
        messagebox.showinfo("情報","画像を拡大してクリップボードにコピーしました！")

def shukusyo():
    kekka = mainShori(1)
    if kekka == 1:
        messagebox.showinfo("情報","画像を縮小してクリップボードにコピーしました！")

root=tk.Tk()
root.title('クリップボードの画像を3倍に拡大か1/3に縮小してクリップボードに保存するツール')
root.geometry("520x300")

btn1=tk.Button(text="クリップボードの画像を3倍に拡大してクリップボードに保存",command=kakudai,foreground='#0000FF')
btn2=tk.Button(text="クリップボードの画像を1/3に縮小してクリップボードに保存",command=shukusyo,foreground='#FF0000')

imageLabel=tk.Label()
lbl1 = tk.Label(text="\n【クリップボードの画像を3倍に拡大か1/3に縮小してクリップボードに保存するツール】\n\n◆概要◆\nクリップボードにコピーされている画像を\n3倍に拡大、もしくは1/3に縮小したうえでクリップボードに上書き保存します。\n\n◆用途◆\nドット絵規格の素材(RPGツクール2000やウディタのようなやつ)を、\nRPGツクールMV・MZで使うために3倍に拡大しなきゃいけない場合\nもしくはそれを修正するために1/3に縮小しなければいけない場合に使います。\n")
lbl2 = tk.Label(text="")

lbl1.pack()
btn1.pack()
lbl2.pack()
btn2.pack()
#imageLabel.pack()

root.mainloop()
